@@ -398,7 +398,8 @@ class ConfigManager:
             "video_color_classification": None,  # Alias for color_detection
             "vehicle_monitoring" : None,
             "fire_smoke_detection": None,
-            "flare_analysis" : None
+            "flare_analysis" : None,
+            "weld_defect_detection" : None,
         }
 
     def register_config_class(self, usecase: str, config_class: type) -> None:
@@ -428,6 +429,16 @@ class ConfigManager:
             return FireSmokeConfig
         except ImportError:
             return None
+
+    def _get_car_damage_config_class(self):
+        """Register a configuration class for a use case."""
+        try:
+            from ..usecases.car_damage_detection import CarDamageConfig
+            return CarDamageConfig
+        except ImportError:
+            return None
+
+
     def _get_parking_space_detection_config_class(self):
         """Register a configuration class for a use case."""
         try:
@@ -475,6 +486,30 @@ class ConfigManager:
             return PedestrianDetectionConfig
         except ImportError:
             return None
+    
+    def age_detection_config_class(self):
+        """Register a configuration class for a use case."""
+        try:
+            from ..usecases.age_detection import AgeDetectionConfig
+            return AgeDetectionConfig
+        except ImportError:
+            return None
+        
+    def weld_defect_detection_config_class(self):
+        """Register a configuration class for a use case."""
+        try:
+            from ..usecases.weld_defect_detection import WeldDefectConfig
+            return WeldDefectConfig
+        except ImportError:
+            return None
+        
+    def price_tag_detection_config_class(self):
+        """Register a configuration class for a use case."""
+        try:
+            from ..usecases.price_tag_detection import PriceTagConfig
+            return PriceTagConfig
+        except ImportError:
+            return None
 
     def create_config(self, usecase: str, category: Optional[str] = None, **kwargs) -> BaseConfig:
         """
@@ -610,6 +645,22 @@ class ConfigManager:
                 **kwargs
             )
 
+        elif usecase == "car_damage_detection":
+            # Import here to avoid circular import
+            from ..usecases.car_damage_detection import CarDamageConfig
+
+            # Handle nested configurations
+            alert_config = kwargs.pop("alert_config", None)
+            if alert_config and isinstance(alert_config, dict):
+                alert_config = AlertConfig(**alert_config)
+
+            config = CarDamageConfig(
+                category=category or "normal",
+                usecase=usecase,
+                alert_config=alert_config,
+                **kwargs
+            )
+
         elif usecase == "pothole_segmentation":
             # Import here to avoid circular import
             from ..usecases.pothole_segmentation import PotholeConfig
@@ -725,7 +776,7 @@ class ConfigManager:
                 alert_config = AlertConfig(**alert_config)
 
             config = FaceEmotionConfig(
-                category=category or "emotion",
+                category=category or "general",
                 usecase=usecase,
                 alert_config=alert_config,
                 **kwargs
@@ -759,6 +810,50 @@ class ConfigManager:
                 alert_config=alert_config,
                 **kwargs
             )
+        elif usecase == "weld_defect_detection":
+            # Import here to avoid circular import
+            from ..usecases.weld_defect_detection import WeldDefectConfig
+            alert_config = kwargs.pop("alert_config", None)
+            if alert_config and isinstance(alert_config, dict):
+                alert_config = AlertConfig(**alert_config)
+            config = WeldDefectConfig(
+                category=category or "weld",
+                usecase=usecase,
+                alert_config=alert_config,
+                **kwargs
+            )
+        
+        elif usecase == "age_detection":
+            # Import here to avoid circular import
+            from ..usecases.age_detection import AgeDetectionConfig
+
+            # Handle nested configurations
+            alert_config = kwargs.pop("alert_config", None)
+            if alert_config and isinstance(alert_config, dict):
+                alert_config = AlertConfig(**alert_config)
+
+            config = AgeDetectionConfig(
+                category=category or "security",
+                usecase=usecase,
+                alert_config=alert_config,
+                **kwargs
+            )
+
+        elif usecase == "price_tag_detection":
+            # Import here to avoid circular import
+            from ..usecases.price_tag_detection import PriceTagConfig
+
+            # Handle nested configurations
+            alert_config = kwargs.pop("alert_config", None)
+            if alert_config and isinstance(alert_config, dict):
+                alert_config = AlertConfig(**alert_config)
+
+            config = PriceTagConfig(
+                category=category or "retail",
+                usecase=usecase,
+                alert_config=alert_config,
+                **kwargs
+            )
             
         else:
             raise ConfigValidationError(f"Unknown use case: {usecase}")
@@ -872,6 +967,12 @@ class ConfigManager:
             default_config = FireSmokeConfig()
             return default_config.to_dict()
 
+        elif usecase == "car_damage_detection":
+            # Import here to avoid circular import
+            from ..usecases.car_damage_detection import CarDamageConfig
+            default_config = CarDamageConfig()
+            return default_config.to_dict()
+
         elif usecase == "pothole_segmentation":
             # Import here to avoid circular import
             from ..usecases.pothole_segmentation import PotholeConfig
@@ -883,6 +984,11 @@ class ConfigManager:
             from ..usecases.vehicle_monitoring import VehicleMonitoringConfig
             default_config = VehicleMonitoringConfig()
             return default_config.to_dict()
+        elif usecase == "weld_defect_detection":
+            # Import here to avoid circular import
+            from ..usecases.weld_defect_detection import WeldDefectConfig
+            default_config = WeldDefectConfig()
+            return default_config.to_dict()
         elif usecase == "video_color_classification":
             from ..usecases.color_detection import ColorDetectionConfig
             default_config = ColorDetectionConfig()
@@ -916,6 +1022,16 @@ class ConfigManager:
             from ..usecases.pedestrian_detection import PedestrianDetectionConfig
             default_config = PedestrianDetectionConfig()
             return default_config.to_dict()
+        elif usecase == "age_detection":
+            # Import here to avoid circular import
+            from ..usecases.age_detection import AgeDetectionConfig
+            default_config = AgeDetectionConfig()
+            return default_config.to_dict()
+        elif usecase == "price_tag_detection":
+            # Import here to avoid circular import
+            from ..usecases.price_tag_detection import PriceTagConfig
+            default_config = PriceTagConfig()
+            return default_config.to_dict()
         elif usecase not in self._config_classes:
             raise ConfigValidationError(f"Unsupported use case: {usecase}")
 
