@@ -73,7 +73,7 @@ class AdvancedCustomerServiceUseCase(BaseProcessor):
             staff_count = sum(1 for d in detections if d.get('category') == 'staff')
             customer_count = sum(1 for d in detections if d.get('category') == 'customer')
             total_people = staff_count + customer_count
-            # Event (match people_counting)
+            # Event
             event = {
                 "type": "advanced_customer_service",
                 "stream_time": datetime.datetime.utcnow().strftime("%Y-%m-%d-%H:%M:%S UTC"),
@@ -84,7 +84,7 @@ class AdvancedCustomerServiceUseCase(BaseProcessor):
                 "frame_id": str(frame_id)
             }
             frame_events[str(frame_id)] = [event]
-            # Tracking stats (match people_counting fields)
+            # Tracking stats 
             # Use the full summary for each frame's human_text, but exclude queue_lengths_by_area, service_proximity_threshold, and real_time_occupancy
             # Prepare a filtered analytics_results for summary
             filtered_analytics = dict(analytics_results)
@@ -96,6 +96,14 @@ class AdvancedCustomerServiceUseCase(BaseProcessor):
                 filtered_analytics["service_area_analytics"].pop("service_proximity_threshold", None)
             filtered_analytics.pop("real_time_occupancy", None)
             full_summary = self._generate_summary(filtered_analytics, [])
+            # Safely handle frame_id type for total_frames_processed
+            if isinstance(frame_id, int):
+                total_frames_proc = total_frames_processed + frame_id
+            else:
+                try:
+                    total_frames_proc = total_frames_processed + int(frame_id)
+                except Exception:
+                    total_frames_proc = total_frames_processed
             tracking_stat = {
                 "tracking_start_time": datetime.datetime.utcnow().strftime("%Y-%m-%d"),
                 "all_results_for_tracking": {
@@ -116,7 +124,7 @@ class AdvancedCustomerServiceUseCase(BaseProcessor):
                 "human_text": full_summary,
                 "frame_id": str(frame_id),
                 "frames_in_this_call": 1,
-                "total_frames_processed": total_frames_processed + int(frame_id),
+                "total_frames_processed": total_frames_proc,
                 "current_frame_number": str(frame_id),
                 "global_frame_offset": global_frame_offset
             }
@@ -200,7 +208,7 @@ class AdvancedCustomerServiceUseCase(BaseProcessor):
                     "type": "number",
                     "minimum": 0.0, 
                     "maximum": 1.0,
-                    "default": 0.5,
+                    "default": 0.2,
                     "description": "Minimum confidence threshold for detections"
                 },
                 "customer_areas": {
@@ -313,7 +321,7 @@ class AdvancedCustomerServiceUseCase(BaseProcessor):
         defaults = {
             "category": self.category,
             "usecase": self.name,
-            "confidence_threshold": 0.5,
+            "confidence_threshold": 0.2,
             "enable_tracking": True,
             "enable_analytics": True,
             "enable_journey_analysis": True,
@@ -344,127 +352,83 @@ class AdvancedCustomerServiceUseCase(BaseProcessor):
                     context=context
                 )
 
-            if stream_info is not None:
-                if context is None:
-                    context = ProcessingContext()
-                context.stream_info = stream_info
-
+            # Initialize processing context if not provided
             if context is None:
                 context = ProcessingContext()
 
-            self._service_proximity_threshold = config.service_proximity_threshold
-
+            # Detect input format
             input_format = match_results_structure(data)
             context.input_format = input_format
             context.confidence_threshold = config.confidence_threshold
             context.enable_tracking = config.enable_tracking
 
-            self.logger.info(f"Processing advanced customer service with format: {input_format.value}")
+            # Set proximity threshold
+            self._service_proximity_threshold = config.service_proximity_threshold
 
-            self._initialize_areas(config.customer_areas, config.staff_areas, config.service_areas)
+            # Ensure area attributes are initialized
+            if not hasattr(self, 'customer_areas') or not hasattr(self, 'staff_areas') or not hasattr(self, 'service_areas'):
+                self._initialize_areas(
+                    getattr(config, 'customer_areas', {}),
+                    getattr(config, 'staff_areas', {}),
+                    getattr(config, 'service_areas', {})
+                )
 
-            processed_data = data
-            if config.confidence_threshold is not None:
-                processed_data = filter_by_confidence(processed_data, config.confidence_threshold)
-                self.logger.debug(f"Applied confidence filtering with threshold {config.confidence_threshold}")
+            # 1. Extract detections
+            processed_data = data if isinstance(data, dict) else {}
+            detections = self._extract_detections(data)
 
-            if hasattr(config, 'index_to_category') and config.index_to_category:
-                processed_data = apply_category_mapping(processed_data, config.index_to_category)
-                self.logger.debug("Applied category mapping")
+            # Assign staff/customer by area (in-place)
+            assign_person_by_area(detections, getattr(config, 'customer_areas', {}), getattr(config, 'staff_areas', {}))
 
-            detections = self._extract_detections(processed_data)
-            assign_person_by_area(
-                detections,
-                getattr(config, 'customer_areas', {}),
-                getattr(config, 'staff_areas', {})
-            )
             staff_detections, customer_detections = self._categorize_detections(
-                detections, config.staff_categories, config.customer_categories
+                detections,
+                config.staff_categories,
+                config.customer_categories
             )
-            self.logger.debug(f"Extracted {len(staff_detections)} staff and {len(customer_detections)} customer detections")
-
-            self._maybe_reset_chunk()
-            self._update_chunk_tracking(customer_detections)
-
             current_time = time.time()
+            # 2. Process analytics
             analytics_results = self._process_comprehensive_analytics(
-                staff_detections, customer_detections, config, current_time
+                staff_detections,
+                customer_detections,
+                config,
+                current_time
             )
-
-            # --- FIX: Ensure agg_summary is top-level and events/tracking_stats are dicts ---
-            if isinstance(processed_data, dict):
-                agg_summary = self._generate_per_frame_agg_summary(processed_data, analytics_results, config, context, stream_info)
-            else:
-                agg_summary = {"events": {}, "tracking_stats": {}}
-
-            # --- FIX: Ensure raw_output is always a list ---
-            if not isinstance(analytics_results.get("raw_output", []), list):
-                analytics_results["raw_output"] = [analytics_results.get("raw_output", {})]
-
-            insights = self._generate_insights(analytics_results, config)
-            alerts = self._check_alerts(analytics_results, config)
-            summary = self._generate_summary(analytics_results, alerts)
-            predictions = self._extract_predictions(processed_data)
-
-            context.mark_completed()
-
-
-
-            # --- REPLACE outer agg_summary with inner if present ---
-            # If analytics_results contains processed_data.agg_summary, use that as the output agg_summary
-            inner_agg_summary = None
-            if "processed_data" in analytics_results and isinstance(analytics_results["processed_data"], dict):
-                pd = analytics_results["processed_data"]
-                if "agg_summary" in pd and isinstance(pd["agg_summary"], dict):
-                    inner_agg_summary = pd["agg_summary"]
-            if inner_agg_summary:
-                agg_summary = inner_agg_summary
-
-            # Ensure tracking_stats and events are dicts keyed by frame_id
-            if "tracking_stats" in agg_summary and isinstance(agg_summary["tracking_stats"], list):
-                # If tracking_stats is a list with a dict containing tracking_stats, flatten
-                for item in agg_summary["tracking_stats"]:
-                    if isinstance(item, dict) and "tracking_stats" in item:
-                        agg_summary["tracking_stats"] = item["tracking_stats"]
-                        break
-
-            if "events" in agg_summary and isinstance(agg_summary["events"], list):
-                for item in agg_summary["events"]:
-                    if isinstance(item, dict) and "events" in item:
-                        agg_summary["events"] = item["events"]
-                        break
-
-            # Compose result data with flattened agg_summary
-            result_data = dict(analytics_results)
-            result_data["agg_summary"] = agg_summary
-
-
-            # Ensure raw_output is always a list, including inside model_output
+            # 3. Generate agg_summary
+            agg_summary = self._generate_per_frame_agg_summary(
+                processed_data,
+                analytics_results,
+                config,
+                context,
+                stream_info=stream_info
+            )
+            # 4. Compose result data
+            # Only include agg_summary (with events and tracking_stats) in result_data
+            result_data = {"agg_summary": agg_summary}
+            # 5. Ensure raw_output is always a list in result_data and in model_output if present
+            if "raw_output" in result_data and not isinstance(result_data["raw_output"], list):
+                result_data["raw_output"] = [result_data["raw_output"]]
             if "model_output" in result_data:
                 mo = result_data["model_output"]
                 if isinstance(mo, dict) and "raw_output" in mo and not isinstance(mo["raw_output"], list):
                     mo["raw_output"] = [mo["raw_output"]]
-            if not isinstance(result_data.get("raw_output", []), list):
-                result_data["raw_output"] = [result_data.get("raw_output", {})]
-
+            # 6. (Skip insights, alerts, summary, predictions for agg_summary-only output)
+            # 7. Create result object
             result = self.create_result(
                 data=result_data,
                 usecase=self.name,
                 category=self.category,
                 context=context
             )
-
-            result.summary = summary
-            result.insights = insights
-            result.predictions = predictions
-            result.metrics = analytics_results.get("business_metrics", {})
-
+            # result.summary = summary
+            # result.insights = insights
+            # result.predictions = predictions  
+            # result.metrics = analytics_results.get("business_metrics", {})
             if not config.customer_areas and not config.staff_areas:
                 result.add_warning("No customer or staff areas defined - using global analysis only")
-
             if config.service_proximity_threshold > 250:
                 result.add_warning(f"High service proximity threshold ({config.service_proximity_threshold}) may miss interactions")
-
+            if context:
+                context.mark_completed()
             self.logger.info(f"Advanced customer service analysis completed successfully in {result.processing_time:.2f}s")
             return result
 
@@ -1228,29 +1192,22 @@ class AdvancedCustomerServiceUseCase(BaseProcessor):
         return "\n".join(summary)
     
     def _extract_predictions(self, data: Any) -> Dict[str, List[Dict[str, Any]]]:
-        """Extract predictions from processed data for API compatibility, grouped by frame number if available."""
-        predictions = {}
+        """Extract predictions from processed data for API compatibility, flat list"""
+        predictions = []
         try:
             if isinstance(data, dict):
-                # Frame-based or tracking format
-                for frame_id, items in data.items():
-                    if not isinstance(items, list):
-                        continue
-                    frame_preds = []
-                    for item in items:
-                        if isinstance(item, dict):
-                            pred = {
-                                "category": item.get("category", item.get("class", "unknown")),
-                                "confidence": item.get("confidence", item.get("score", 0.0)),
-                                "bounding_box": item.get("bounding_box", item.get("bbox", {})),
-                                "track_id": item.get("track_id")
-                            }
-                            frame_preds.append(pred)
-                    if frame_preds:
-                        predictions[str(frame_id)] = frame_preds
+                for items in data.values():
+                    if isinstance(items, list):
+                        for item in items:
+                            if isinstance(item, dict):
+                                pred = {
+                                    "category": item.get("category", item.get("class", "unknown")),
+                                    "confidence": item.get("confidence", item.get("score", 0.0)),
+                                    "bounding_box": item.get("bounding_box", item.get("bbox", {})),
+                                    "track_id": item.get("track_id")
+                                }
+                                predictions.append(pred)
             elif isinstance(data, list):
-                # If not frame-based, put all predictions under a generic key
-                predictions["0"] = []
                 for item in data:
                     if isinstance(item, dict):
                         pred = {
@@ -1259,7 +1216,7 @@ class AdvancedCustomerServiceUseCase(BaseProcessor):
                             "bounding_box": item.get("bounding_box", item.get("bbox", {})),
                             "track_id": item.get("track_id")
                         }
-                        predictions["0"].append(pred)
+                        predictions.append(pred)
         except Exception as e:
             self.logger.warning(f"Failed to extract predictions: {str(e)}")
         return predictions
\ No newline at end of file
