@@ -191,14 +191,14 @@ class VehicleMonitoringUseCase(BaseProcessor):
         
         is_video_chunk = stream_info.get("input_settings", {}).get("is_video_chunk", False)
         
-        if is_video_chunk:
-            # For video chunks, use video_timestamp from stream_info
-            video_timestamp = stream_info.get("video_timestamp", 0.0)
-            return self._format_timestamp_for_video(video_timestamp)
-        elif stream_info.get("input_settings", {}).get("stream_type","video_file")=="video_file":
+        # if is_video_chunk:
+        #     # For video chunks, use video_timestamp from stream_info
+        #     video_timestamp = stream_info.get("video_timestamp", 0.0)
+        #     return self._format_timestamp_for_video(video_timestamp)
+        if stream_info.get("input_settings", {}).get("stream_type","video_file")=="video_file":
             # If video format, return video timestamp
             stream_time_str = stream_info.get("video_timestamp", "")
-            return stream_time_str
+            return stream_time_str[:8]
         else:
             # For streams, use stream_time from stream_info
             stream_time_str = stream_info.get("stream_time", "")
@@ -547,36 +547,59 @@ class VehicleMonitoringUseCase(BaseProcessor):
 
         return events
 
-
-    def _generate_tracking_stats(self, counting_summary: Dict, insights: List[str], summary: str, config: VehicleMonitoringConfig, frame_number: Optional[int] = None, stream_info: Optional[Dict[str, Any]] = None) -> List[Dict]:
+    def _generate_tracking_stats(
+            self,
+            counting_summary: Dict,
+            insights: List[str],
+            summary: str,
+            config: VehicleMonitoringConfig,
+            frame_number: Optional[int] = None,
+            stream_info: Optional[Dict[str, Any]] = None
+    ) -> List[Dict]:
         """Generate structured tracking stats for the output format with frame-based keys, including track_ids_info."""
+
+
         frame_key = str(frame_number) if frame_number is not None else "current_frame"
         tracking_stats = [{frame_key: []}]
         frame_tracking_stats = tracking_stats[0][frame_key]
+
         total_vehicles = counting_summary.get("total_count", 0)
-        total_vehicle_counts = counting_summary.get("total_vehicle_counts", 0)
+        total_vehicle_counts = counting_summary.get("total_vehicle_counts", {})
         cumulative_total = sum(total_vehicle_counts.values()) if total_vehicle_counts else 0
-        # Add detailed track_ids_info (like people_counting)
+        per_category_count = counting_summary.get("per_category_count", {})
+
+
         track_ids_info = self._get_track_ids_info(counting_summary.get("detections", []))
-                # Get formatted timestamps
+
         current_timestamp = self._get_current_timestamp_str(stream_info)
         start_timestamp = self._get_start_timestamp_str(stream_info)
 
-        # Build human-readable summary string in new format
         human_text_lines = []
-        
+
         # CURRENT FRAME section
         human_text_lines.append(f"CURRENT FRAME @ {current_timestamp}:")
         if total_vehicles > 0:
-            human_text_lines.append(f"    - Vehicles Detected: {total_vehicles}")
+            category_counts = [f"{count} {cat}" for cat, count in per_category_count.items()]
+            if len(category_counts) == 1:
+                vehicles_text = category_counts[0] + " detected"
+            elif len(category_counts) == 2:
+                vehicles_text = f"{category_counts[0]} and {category_counts[1]} detected"
+            else:
+                vehicles_text = f"{', '.join(category_counts[:-1])}, and {category_counts[-1]} detected"
+            human_text_lines.append(f"\t- {vehicles_text}")
         else:
-            human_text_lines.append("    - No Vehicles detected")
-        
-        human_text_lines.append("")  # Empty line for spacing
-        
+            human_text_lines.append(f"\t- No vehicles detected")
+
+        human_text_lines.append("")  # spacing
+
         # TOTAL SINCE section
         human_text_lines.append(f"TOTAL SINCE {start_timestamp}:")
-        human_text_lines.append(f"    - Total Vehicles Detected: {cumulative_total}")
+        human_text_lines.append(f"\t- Total Vehicles Detected: {cumulative_total}")
+        # Add category-wise vehicle counts
+        if total_vehicle_counts:
+            for cat, count in total_vehicle_counts.items():
+                if count > 0:  # Only include categories with non-zero counts
+                    human_text_lines.append(f"\t- {cat}: {count}")
 
         human_text = "\n".join(human_text_lines)
 
@@ -592,12 +615,10 @@ class VehicleMonitoringUseCase(BaseProcessor):
             "global_frame_offset": getattr(self, '_global_frame_offset', 0),
             "local_frame_id": frame_key
         }
+
         frame_tracking_stats.append(tracking_stat)
-
         return tracking_stats
 
-
-
     def _count_categories(self, detections: list, config: VehicleMonitoringConfig) -> dict:
         """
         Count the number of detections per category and return a summary dict.
@@ -868,4 +889,3 @@ class VehicleMonitoringUseCase(BaseProcessor):
     def _set_tracking_start_time(self) -> None:
         """Set the tracking start time to the current time."""
         self._tracking_start_time = time.time()
-
